@@ -63,7 +63,10 @@ input and write the converted data to its standard output.")
   "^[^:]...............................................................$")
 (defconst binhex-end-line ":$")
 
-(defvar binhex-temporary-file-directory "/tmp/")
+(defvar binhex-temporary-file-directory
+  (cond ((fboundp 'temp-directory) (temp-directory))
+	((boundp 'temporary-file-directory) temporary-file-directory)
+	("/tmp/")))
 
 (if (string-match "XEmacs" emacs-version)
     (defalias 'binhex-insert-char 'insert-char)
