@@ -68,6 +68,10 @@
 (defvar mm-uu-identifier-alist
   '((?% . postscript) (?b . uu) (?: . binhex) (?# . shar)))
 
+(defvar mm-dissect-disposition "inline"
+  "The default disposition of uu parts.
+This can be either \"inline\" or \"attachment\".")
+
 ;;;### autoload
 
 (defun mm-uu-dissect ()
@@ -133,9 +137,9 @@
 				    (mailcap-extension-to-mime 
 				     (match-string 0 file-name)))
 			       "application/octet-stream"))
-		     mm-uu-decode-function nil 
+		     'x-uuencode nil 
 		     (if (and file-name (not (equal file-name "")))
-			 (list "inline" (cons 'filename file-name)))))
+			 (list mm-dissect-disposition (cons 'filename file-name)))))
 	      ((eq type 'binhex)
 	       (mm-make-handle (mm-uu-copy-to-buffer start-char end-char) 
 		     (list (or (and file-name
@@ -143,9 +147,9 @@
 				    (mailcap-extension-to-mime 
 				     (match-string 0 file-name)))
 			       "application/octet-stream"))
-		     mm-uu-binhex-decode-function nil 
+		     'x-binhex nil 
 		     (if (and file-name (not (equal file-name "")))
-			 (list "inline" (cons 'filename file-name)))))
+			 (list mm-dissect-disposition (cons 'filename file-name)))))
 	      ((eq type 'shar)
 	       (mm-make-handle (mm-uu-copy-to-buffer start-char end-char) 
 		     '("application/x-shar")))) 
