@@ -454,6 +454,11 @@ parameter.  It should return nil, `warn' or `delete'."
   :group 'nnmail
   :type '(repeat symbol))
 
+(defcustom nnmail-split-header-length-limit 1024
+  "Header lines longer than this limit are excluded from the split function."
+  :group 'nnmail
+  :type 'integer)
+
 ;;; Internal variables.
 
 (defvar nnmail-split-history nil
@@ -1063,8 +1068,8 @@ FUNC will be called with the group name to determine the article number."
 	(goto-char (point-min))
 	(while (not (eobp))
 	  (end-of-line)
-	  (if (> (current-column) 1024)
-	      (gnus-delete-line)
+	  (if (> (current-column) nnmail-split-header-length-limit)
+	      (delete-region (point) (progn (end-of-line) (point)))
 	    (forward-line 1)))
 	;; Allow washing.
 	(goto-char (point-min))
